@@ -3,13 +3,14 @@ package File::Canonicalizer;
 use 5.006;
 use strict;
 use warnings FATAL => 'all';
+use English;
 
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(file_canonicalizer);
 
 use Carp;
-our $VERSION = '0.02';
+our $VERSION = '0.10';
 
 sub file_canonicalizer {
    my ( $inp_file                                       # 1
@@ -22,13 +23,15 @@ sub file_canonicalizer {
       , $convert_to_lowercased                          # 8
       , $remove_leading_zeroes                          # 9
       , $sort_lines                                     #10
-      , $replaced_substring                             #11
-      , $replacing_substring                            #12
+      , $aref_replacements                              #11
       ) = @_ ;
 
    my %lines ;
    my $INP;
    my $OUT;
+   my $i ;
+   my $replaced_pattern;
+   my $replacement;
 
    unless ($inp_file) { $inp_file = '&STDIN'; } 
    open ($INP, "<$inp_file") || croak "Error: Can't open file \"$inp_file\" for read: $!"; 
@@ -37,22 +40,34 @@ sub file_canonicalizer {
 
    while (<$INP>)
    {
+     chomp;
      if ($remove_comments_started_with_RE) { s/$remove_comments_started_with_RE.+$//; }
-     if (defined $replacing_substring) { s/$replaced_substring/$replacing_substring/g; }
      if ($replace_adjacent_tabs_and_spaces_with_1_space) { s/[ \t]+/ /g; }
      if ($replace_adjacent_slashes_with_single_slash) { s#/+#/#g; }
      if ($remove_empty_lines) { (/^\s*$/) && next; }
      if ($remove_white_char_from_line_edges) { s/(^[ \t]*|[ \t]*$)//g; }
      if ($convert_to_lowercased) { $_ = lc; }
      if ($remove_leading_zeroes) { s/(\W)0+(\d)/$1$2/g; }
+
+     if (defined $aref_replacements)
+     {
+        $i = 0;
+        REPLACEMENTS: while (1)
+        {
+           ($replaced_pattern, $replacement) = (@{$aref_replacements})[$i++,$i++];
+           (defined $replacement) || last REPLACEMENTS;
+           s/$replaced_pattern/$replacement/g;
+        }
+     }
+
      if ($sort_lines) { $lines{$_} = undef; next; }
-     print $OUT "$_" || croak "Error: Can't write to $out_file: $!";
+     print $OUT "$_\n" || croak "Error: Can't write to $out_file: $!";
    }
 
    if ($sort_lines)
    {
       for (sort keys %lines)
-      {  print $OUT "$_" || croak "Error: Can't write to $out_file: $!"; }
+      {  print $OUT "$_\n" || croak "Error: Can't write to $out_file: $!"; }
    }
 
    close $OUT; 
@@ -71,13 +86,17 @@ File::Canonicalizer - ASCII file canonicalizer
 
    use File::Canonicalizer;
 
-   file_canonicalizer ('input_file','canonical_output_file', '',4,5,6,7,8,9,10);
+   $aref = [ 'replaced_pattern1', 'replacement1',
+             'replaced_pattern2', 'replacement2',
+             ... ];
+
+   file_canonicalizer ('input_file','canonical_output_file', '',4,5,6,7,8,9,10, $aref);
 
 =head1 DESCRIPTION
 
 Sometimes files must be compared semantically, that is their contents, not their forms
 are to be compared.
-Following two files have different forms, but contain identical information:
+The following two files have different forms, but contain identical information:
 
 file_A
 
@@ -99,15 +118,26 @@ file_B
    Birth Date: 1961/08/04
 
 Some differences between forms of these files are:
- - arbitrary line order
- - arbitrary character cases
- - arbitrary leading zeroes for numbers
- - arbitrary amounts of white characters
- - arbitrary comments
- - arbitrary empty lines
- - field separators
 
-Usage of file_canonicalizer allows to unify both these files, so that 
+=over 4
+
+=item * arbitrary line order
+
+=item * arbitrary character cases
+
+=item * arbitrary leading zeroes for numbers
+
+=item * arbitrary amounts of white characters
+
+=item * arbitrary comments
+
+=item * arbitrary empty lines
+
+=item * field separators
+
+=back
+
+Using file_canonicalizer allows one to simplify both of these files, so that
 they can be compared with each other.
 
 =head1 SUBROUTINES
@@ -124,8 +154,7 @@ they can be compared with each other.
                       , 'convert_to_lower_cased'                       # 8
                       , 'remove_leading_zeroes_in_numbers'             # 9
                       , 'sort_lines'                                   #10
-                      , <replaced_substring>                           #11
-                      , <replacing_substring>                          #12
+                      , array_reference_to_pairs_replaced_replacement  #11
    );
 
 All parameters, beginning with the 3rd, are interpreted as Boolean values
@@ -138,7 +167,7 @@ In this case the actions, corresponding skipped parameters, will not be executed
 
 =head1 EXAMPLES
 
-Read from STDIN, write to STDOUT and remove all strings, beginning with '#' :
+Read from STDIN, write to STDOUT and remove all substrings, beginning with '#' :
 
    file_canonicalizer ('','','#');
 
@@ -148,17 +177,17 @@ Create canonicalized cron table (on UNIX/Linux) in any of equivalent examples:
    file_canonicalizer('path/cron_table','/tmp/cron_table.canonic','#',4,5, 6,    7,       '',9, 10);
    file_canonicalizer('path/cron_table','/tmp/cron_table.canonic','#',1,1, 1,    1,       '',1, 1);
 
-Canonicalization of files 'file_A' and 'file_B', shown in sesction "DESCRIPTION":
+Canonicalization of files 'file_A' and 'file_B', shown in the section "DESCRIPTION":
 
-   file_canonicalizer('file_A','file_A.canonic','#',1,5,1,1,1,1,10,'\-',':');
-   file_canonicalizer('file_B','file_B.canonic','#',1,5,1,1,1,1,10);
+   file_canonicalizer('file_A','file_A.canonic','#',1,5,1,1,1,1,10, ['\s*-\s*',' : ', '^','<', '$','>']);
+   file_canonicalizer('file_B','file_B.canonic','#',1,5,1,1,1,1,10, ['\s*:\s*',' : ', '^','<', '$','>']);
 
 creates two identical files 'file_A.canonic' and 'file_B.canonic':
 
-   birth date : 1961/8/4
-   first name : barack
-   last name : obama
-   profession : president
+   <birth date : 1961/8/4>
+   <first name : barack>
+   <last name : obama>
+   <profession : president>
 
 =cut
 
@@ -184,20 +213,16 @@ You can also look for information at:
 =over 4
 
 =item * RT: CPAN's request tracker (report bugs here)
-
- http://rt.cpan.org/NoAuth/Bugs.html?Dist=File-Canonicalizer
+ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=File-Canonicalizer>
 
 =item * AnnoCPAN: Annotated CPAN documentation
-
- http://annocpan.org/dist/File-Canonicalizer
+ L<http://annocpan.org/dist/File-Canonicalizer>
 
 =item * CPAN Ratings
-
- http://cpanratings.perl.org/d/File-Canonicalizer
+ L<http://cpanratings.perl.org/d/File-Canonicalizer>
 
 =item * Search CPAN
-
- http://search.cpan.org/dist/File-Canonicalizer/
+ L<http://search.cpan.org/dist/File-Canonicalizer/>
 
 =back
 
@@ -206,7 +231,6 @@ You can also look for information at:
 Copyright 2013 Mart E. Rivilis.
 
 This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
+under the terms of the the Artistic License (2.0).
 
 =cut
